@@ -1,10 +1,11 @@
 package CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets;
+{
+  $CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets::VERSION = '1.012';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.011';
-
 sub available {
     my ( $plugin, $dist ) = @_;
     return ( $dist->parent->package_name eq 'Alien-wxWidgets' );
@@ -27,13 +28,11 @@ __END__
 
 =head1 NAME
 
-CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets - Configure
-Alien::wxWidgets
+CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets - Configure Alien::wxWidgets
 
 =head1 VERSION
 
-This documentation refers to
-C<CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets> version 1.011.
+version 1.012
 
 =head1 SYNOPSIS
 
@@ -96,7 +95,7 @@ through the web interface at L<http://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2012, 2013 Andreas Voegele
+Copyright 2012, 2013 Andreas Voegele
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
