@@ -1,12 +1,13 @@
 package CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin;
+{
+  $CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin::VERSION = '1.012';
+}
 
 use strict;
 use warnings;
 
 use File::Spec qw();
 
-our $VERSION = '1.011';
-
 sub available {
     my ( $plugin, $dist ) = @_;
     return ( $dist->parent->package_name eq 'Mail-SpamAssassin' );
@@ -193,13 +194,11 @@ __END__
 
 =head1 NAME
 
-CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin - Add an init script and
-documentation
+CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin - Add an init script and documentation
 
 =head1 VERSION
 
-This documentation refers to
-C<CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin> version 1.011.
+version 1.012
 
 =head1 SYNOPSIS
 
@@ -258,7 +257,7 @@ through the web interface at L<http://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2012, 2013 Andreas Voegele
+Copyright 2012, 2013 Andreas Voegele
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
